@@ -7,7 +7,7 @@ def print_student_data(student):
   print(f"Last name:    {student.last_name}")
   print(f"Personnummer: {student.personnummer}")
   print(f"LADOK ID:     {student.ladok_id}")
-  print(f"Alice:        {student.alive}")
+  print(f"Alive:        {student.alive}")
 def print_course_data(student, course):
   """Prints the courses"""
   print("Courses:")
